@@ -3,15 +3,13 @@ from string import Formatter
 import django.contrib.admin as admin
 from django.contrib.contenttypes.models import ContentType
 from django.utils.html import escape
-
-from models import Journal, Tag, ObjectData, StringData
-
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.utils.html import escape
 from django.core.urlresolvers import reverse, NoReverseMatch
 
-import actions
+from .models import Journal, Tag, ObjectData, StringData
+from .actions import export_as_csv
+
 
 class ModelAdminFormatter(Formatter):
     def __init__(self, model_admin=None, filter_link=True,
@@ -71,7 +69,7 @@ class JournalAdmin(admin.ModelAdmin):
     )
     date_hierarchy = 'time'
     search_fields = ('message','tag__name','time')
-    actions = [ actions.export_as_csv ]
+    actions = [ export_as_csv ]
 
     class Media:
         css = {
