@@ -1,4 +1,5 @@
-import django_journal
+from django_journal import journal
+
 
 class JournalMiddleware(object):
     '''Add record and error_record methods to the request object to log
@@ -15,13 +16,13 @@ class JournalMiddleware(object):
                 kwargs['user'] = user
             if 'ip' not in kwargs:
                 kwargs['ip'] = ip
-            django_journal.record(tag, template, using=using,**kwargs)
+            journal.record(tag, template, using=using,**kwargs)
         def error_record(tag, template, using=None, **kwargs):
             if 'user' not in kwargs:
                 kwargs['user'] = user
             if 'ip' not in kwargs:
                 kwargs['ip'] = ip
-            django_journal.error_record(tag, template, using=using, **kwargs)
+            journal.error_record(tag, template, using=using, **kwargs)
         request.record = record
         request.error_record = error_record
         return None
